@@ -4,9 +4,14 @@
 
 #Check core dumps restricted?
 coredumpcheck() {
-  coreValue=$(grep -Exic "hard[[:blank:]]+core[[:blank:]]+0" /etc/security/limits.conf)
-  coreValueDefault=$(grep -Exic "\*[[:blank:]]+hard[[:blank:]]+core[[:blank:]]+0" /etc/security/limits.conf)
-  dumpableValue=$(sysctl -b -e fs.suid_dumpable)
+  if [[ -f /etc/security/limits.conf ]]; then
+    coreValue=$(grep -Exic "hard[[:blank:]]+core[[:blank:]]+0" /etc/security/limits.conf)
+    coreValueDefault=$(grep -Exic "\*[[:blank:]]+hard[[:blank:]]+core[[:blank:]]+0" /etc/security/limits.conf)
+  else
+    coreValue=0
+    coreValueDefault=0
+  fi
+  dumpableValue=$(sysctl -n fs.suid_dumpable)
   if { [[ "${coreValue}" == 1 ]] || [[ "${coreValueDefault}" == 1 ]]; } && { [[ "${dumpableValue}" == 0 ]] || [[ "${dumpableValue}" == 2 ]]; }; then
     echo_message '\033[32mRestricted\033[m\n\n' '' '' ''
   else
