@@ -4,7 +4,7 @@
 
 # check cpu nx flag
 nxcheck() {
-  if grep -qFw nx /proc/cpuinfo; then
+  if grep -qFw 'nx' /proc/cpuinfo; then
     echo_message '\033[32mYes\033[m\n\n' '' '' ''
   else
     echo_message '\033[31mNo\033[m\n\n' '' '' ''
